# Copyright (c) 2009 gocept gmbh & co. kg
# See also LICENSE.txt

import gocept.directory.interfaces
import gocept.reference
import grok
import megrok.pagelet
import zope.schema


class NIC(grok.Container):

    grok.implements(gocept.directory.interfaces.INIC)

    vlan = gocept.reference.reference.Reference(
        ensure_integrity=True)
    addresses = gocept.reference.ReferenceCollection(
        ensure_integrity=True, __name__='addresses')

    def __init__(self):
        super(NIC, self).__init__()
        self.addresses = set()
        self.vlan = None

    @property
    def node(self):
        return self.__parent__

    @property
    def title(self):
        return self.node.title + '.' + self.vlan.class_.short


class Index(megrok.pagelet.Pagelet):

    grok.require('gocept.directory.ManageDirectory')


class IAddressAllocation(zope.interface.Interface):

    network = zope.schema.Choice(
        title=u'Network', source=gocept.directory.interfaces.NICNetworks())

    index = zope.schema.Int(
        title=u'Index', required=False,
        description=u'Will be automatically filled if empty.')


class AllocateAddress(gocept.directory.form.Form):

    form_fields = grok.AutoFields(IAddressAllocation)

    @grok.action('Allocate')
    def allocate(self, network, index):
        addr = None
        if index:
            index = int(index)
            ip = network.netaddr[index]
            addr = gocept.directory.network.Address(str(ip))
        self.context.addresses.add(network.allocate(self.context, addr))
        self.status = u'Address allocated.'
        self.redirect(self.url(self.context))


class MACConsistency(gocept.directory.consistency.UniqueResource):

    type_ = 'MAC'

    def resources(self):
        for node in self.directory.nodes:
            for nic in node.nics:
                yield nic.mac, nic.title
