# Copyright (c) 2009 gocept gmbh & co. kg
# See also LICENSE.txt

import grok
import gocept.directory.interfaces
import zope.component
import netaddr
import megrok.pagelet


grok.context(gocept.directory.interfaces.IDirectory)


class IPs(megrok.pagelet.Pagelet):

    grok.require('gocept.directory.ManageDirectory')

    def addresses(self):
        addresses = {}
        for node in self.context.nodes:
            for nic in node.nics:
                for address in nic.addresses:
                    addresses.setdefault(address.ip, [])
                    addresses[address.ip].append(nic)
        addresses = [dict(address=address, nics=nics) for address, nics in addresses.items()]
        return sorted(addresses, key=lambda x:netaddr.IP(x['address']))


class NodeIDs(megrok.pagelet.Pagelet):

    grok.require('gocept.directory.ManageDirectory')

    def ids(self):
        ids = {}
        for node in self.context.nodes:
            ids.setdefault(node.global_id, [])
            ids[node.global_id].append(node)
        return [dict(id=id, nodes=nodes) for id, nodes in ids.items()]


class MACs(megrok.pagelet.Pagelet):

    grok.require('gocept.directory.ManageDirectory')

    def macs(self):
        macs = {}
        for node in self.context.nodes:
            for nic in node.nics:
                macs.setdefault(nic.mac, [])
                macs[nic.mac].append(nic)
        macs = [dict(mac=mac, nics=nics) for mac, nics in macs.items()]
        return sorted(macs, key=lambda x:x['mac'])
